@@ -6,10 +6,14 @@
 ( cd opt/kde/lib ; ln -sf libkopete_oscar.so.2.0.0 libkopete_oscar.so )
 ( cd opt/kde/lib ; rm -rf libkopete_msn_shared.so.0 )
 ( cd opt/kde/lib ; ln -sf libkopete_msn_shared.so.0.0.0 libkopete_msn_shared.so.0 )
+( cd opt/kde/lib ; rm -rf libkopete_videodevice.so.0 )
+( cd opt/kde/lib ; ln -sf libkopete_videodevice.so.0.0.0 libkopete_videodevice.so.0 )
 ( cd opt/kde/lib ; rm -rf libkopete.so )
 ( cd opt/kde/lib ; ln -sf libkopete.so.1.0.0 libkopete.so )
 ( cd opt/kde/lib ; rm -rf libkopete_oscar.so.2 )
 ( cd opt/kde/lib ; ln -sf libkopete_oscar.so.2.0.0 libkopete_oscar.so.2 )
+( cd opt/kde/lib ; rm -rf libkopete_videodevice.so )
+( cd opt/kde/lib ; ln -sf libkopete_videodevice.so.0.0.0 libkopete_videodevice.so )
 ( cd opt/kde/lib ; rm -rf librss.so.1 )
 ( cd opt/kde/lib ; ln -sf librss.so.1.0.0 librss.so.1 )
 ( cd opt/kde/lib ; rm -rf libkopete.so.1 )
@@ -34,8 +38,6 @@
 ( cd opt/kde/share/doc/HTML/en/ksirc ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kwifimanager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kdenetwork-apidocs ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kdenetwork-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/lanbrowser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcontrol/kcmtalkd ; rm -rf common )
